@@ -15,23 +15,22 @@
 from __future__ import annotations
 
 from typing import Any
-from typing import Union
 from typing import NamedTuple
+from typing import Optional
+from typing import Union
 
-from enum import IntEnum
 from enum import Enum
+from enum import IntEnum
 from enum import unique
 from functools import total_ordering
 
 from gi.repository import Gio
-
-from nbxmpp.namespaces import Namespace
 from nbxmpp.const import PresenceShow
+from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import JID
 
 from gajim.common.i18n import _
-from gajim.common.i18n import Q_
-
+from gajim.common.i18n import p_
 
 STOP_EVENT = True
 PROPAGATE_EVENT = False
@@ -215,7 +214,7 @@ class Display(Enum):
 
 
 class URIType(Enum):
-    UNKNOWN = 'unknown'
+    INVALID = 'invalid'
     XMPP = 'xmpp'
     MAIL = 'mail'
     GEO = 'geo'
@@ -223,12 +222,28 @@ class URIType(Enum):
     FILE = 'file'
     AT = 'at'
     TEL = 'tel'
+    OTHER = 'other'
 
 
-class URIAction(Enum):
+# https://xmpp.org/registrar/querytypes.html
+class XmppUriQuery(Enum):
+    NONE = ''
     MESSAGE = 'message'
     JOIN = 'join'
-    SUBSCRIBE = 'subscribe'
+
+    @staticmethod
+    def from_str(s: str) -> Optional[XmppUriQuery]:
+        try:
+            return XmppUriQuery(s)
+        except ValueError:
+            return None
+
+    @staticmethod
+    def from_str_or_none(s: str) -> XmppUriQuery:
+        qtype = XmppUriQuery.from_str(s)
+        if qtype:
+            return qtype
+        return XmppUriQuery.NONE
 
 
 class MUCJoinedState(Enum):
@@ -238,7 +253,7 @@ class MUCJoinedState(Enum):
     CREATING = 'creating'
     CAPTCHA_REQUEST = 'captcha in progress'
     CAPTCHA_FAILED = 'captcha failed'
-    PASSWORD_REQUEST = 'password request'
+    PASSWORD_REQUEST = 'password request'  # noqa: S105
 
     def __str__(self):
         return self.name
@@ -345,21 +360,21 @@ class CallType(Enum):
 
 
 MUC_CREATION_EXAMPLES = [
-    (Q_('?Group chat name:Team'),
-     Q_('?Group chat description:Project discussion'),
-     Q_('?Group chat address:team')),
-    (Q_('?Group chat name:Family'),
-     Q_('?Group chat description:Spring gathering'),
-     Q_('?Group chat address:family')),
-    (Q_('?Group chat name:Vacation'),
-     Q_('?Group chat description:Trip planning'),
-     Q_('?Group chat address:vacation')),
-    (Q_('?Group chat name:Repairs'),
-     Q_('?Group chat description:Local help group'),
-     Q_('?Group chat address:repairs')),
-    (Q_('?Group chat name:News'),
-     Q_('?Group chat description:Local news and reports'),
-     Q_('?Group chat address:news')),
+    (p_('Group chat name', 'Team'),
+     p_('Group chat description', 'Project discussion'),
+     p_('Group chat address', 'team')),
+    (p_('Group chat name', 'Family'),
+     p_('Group chat description', 'Spring gathering'),
+     p_('Group chat address', 'family')),
+    (p_('Group chat name', 'Vacation'),
+     p_('Group chat description', 'Trip planning'),
+     p_('Group chat address', 'vacation')),
+    (p_('Group chat name', 'Repairs'),
+     p_('Group chat description', 'Local help group'),
+     p_('Group chat address', 'repairs')),
+    (p_('Group chat name', 'News'),
+     p_('Group chat description', 'Local news and reports'),
+     p_('Group chat address', 'news')),
 ]
 
 
@@ -894,7 +909,6 @@ COMMON_FEATURES = [
     Namespace.HASHES_BLAKE2B_512,
     Namespace.JINGLE,
     Namespace.JINGLE_FILE_TRANSFER_5,
-    Namespace.JINGLE_XTLS,
     Namespace.JINGLE_BYTESTREAM,
     Namespace.JINGLE_IBB,
     Namespace.AVATAR_METADATA + '+notify',
@@ -913,22 +927,22 @@ SHOW_LIST = [
 ]
 
 SHOW_STRING = {
-    'dnd': _('Busy'),
-    'xa': _('Not Available'),
-    'chat': _('Free for Chat'),
-    'online': Q_('?user status:Available'),
+    'dnd': p_('User status', 'Busy'),
+    'xa': p_('User status', 'Not Available'),
+    'chat': p_('User status', 'Free for Chat'),
+    'online': p_('User status', 'Available'),
     'connecting': _('Connecting'),
-    'away': _('Away'),
+    'away': p_('User status', 'Away'),
     'offline': _('Offline'),
 }
 
 SHOW_STRING_MNEMONIC = {
-    'dnd': _('_Busy'),
-    'xa': _('_Not Available'),
-    'chat': _('_Free for Chat'),
-    'online': Q_('?user status:_Available'),
+    'dnd': p_('User status', '_Busy'),
+    'xa': p_('User status', '_Not Available'),
+    'chat': p_('User status', '_Free for Chat'),
+    'online': p_('User status', '_Available'),
     'connecting': _('Connecting'),
-    'away': _('A_way'),
+    'away': p_('User status', 'A_way'),
     'offline': _('_Offline'),
 }
 
@@ -936,97 +950,6 @@ GAJIM_FAQ_URI = 'https://dev.gajim.org/gajim/gajim/wikis/help/gajimfaq'
 GAJIM_WIKI_URI = 'https://dev.gajim.org/gajim/gajim/wikis'
 GAJIM_SUPPORT_JID = 'gajim@conference.gajim.org'
 
-URI_SCHEMES = {
-    'aaa://',
-    'aaas://',
-    'acap://',
-    'cap://',
-    'cid:',
-    'crid://',
-    'data:',
-    'dav:',
-    'dict://',
-    'dns:',
-    'fax:',
-    'file:/',
-    'ftp://',
-    'geo:',
-    'go:',
-    'gopher://',
-    'h323:',
-    'http://',
-    'https://',
-    'iax:',
-    'icap://',
-    'im:',
-    'imap://',
-    'info:',
-    'ipp://',
-    'iris:',
-    'iris.beep:',
-    'iris.xpc:',
-    'iris.xpcs:',
-    'iris.lwz:',
-    'ldap://',
-    'mailto:',
-    'mid:',
-    'modem:',
-    'msrp://',
-    'msrps://',
-    'mtqp://',
-    'mupdate://',
-    'news:',
-    'nfs://',
-    'nntp://',
-    'opaquelocktoken:',
-    'pop://',
-    'pres:',
-    'prospero://',
-    'rtsp://',
-    'service:',
-    'sip:',
-    'sips:',
-    'sms:',
-    'snmp://',
-    'soap.beep://',
-    'soap.beeps://',
-    'tag:',
-    'tel:',
-    'telnet://',
-    'tftp://',
-    'thismessage:/',
-    'tip://',
-    'tv:',
-    'urn://',
-    'vemmi://',
-    'xmlrpc.beep://',
-    'xmlrpc.beeps://',
-    'xmpp:',
-    'z39.50r://',
-    'z39.50s://',
-    'about:',
-    'apt:',
-    'cvs://',
-    'daap://',
-    'ed2k://',
-    'feed:',
-    'fish://',
-    'git://',
-    'iax2:',
-    'irc://',
-    'ircs://',
-    'ldaps://',
-    'magnet:',
-    'mms://',
-    'rsync://',
-    'ssh://',
-    'svn://',
-    'sftp://',
-    'smb://',
-    'webcal://',
-    'aesgcm://',
-}
-
 
 # This is an excerpt of Media Types from
 # https://www.iana.org/assignments/media-types/media-types.xhtml
