@@ -22,32 +22,32 @@ import locale
 import logging
 from collections import defaultdict
 
-from gi.repository import Gtk
 from gi.repository import Gdk
-from gi.repository import Pango
 from gi.repository import GObject
+from gi.repository import Gtk
+from gi.repository import Pango
 
 from gajim.common import app
 from gajim.common import passwords
+from gajim.common import types
 from gajim.common.const import ClientState
 from gajim.common.i18n import _
-from gajim.common.i18n import Q_
+from gajim.common.i18n import p_
 from gajim.common.settings import AllSettingsT
-from gajim.common import types
 
-from .dialogs import DialogButton
-from .dialogs import ConfirmationDialog
-from .const import Setting
-from .const import SettingKind
-from .const import SettingType
-from .menus import build_accounts_menu
-from .settings import SettingsDialog
-from .settings import SettingsBox
-from .settings import PopoverSetting
-from .util import get_app_window
-from .util import open_window
+from gajim.gtk.const import Setting
+from gajim.gtk.const import SettingKind
+from gajim.gtk.const import SettingType
+from gajim.gtk.dialogs import ConfirmationDialog
+from gajim.gtk.dialogs import DialogButton
+from gajim.gtk.menus import build_accounts_menu
+from gajim.gtk.settings import PopoverSetting
+from gajim.gtk.settings import SettingsBox
+from gajim.gtk.settings import SettingsDialog
+from gajim.gtk.util import get_app_window
+from gajim.gtk.util import open_window
 
-log = logging.getLogger('gajim.gui.accounts')
+log = logging.getLogger('gajim.gtk.accounts')
 
 
 class AccountsWindow(Gtk.ApplicationWindow):
@@ -186,8 +186,8 @@ class Settings(Gtk.ScrolledWindow):
         self.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
         self._stack = Gtk.Stack(vhomogeneous=False)
         self._stack.set_transition_type(Gtk.StackTransitionType.CROSSFADE)
+        self._stack.get_style_context().add_class('settings-stack')
         self._stack.add_named(AddNewAccountPage(), 'add-account')
-        self.get_style_context().add_class('accounts-settings')
 
         self.add(self._stack)
         self._page_signal_ids: dict[GenericSettingPage, int] = {}
@@ -236,7 +236,8 @@ class AccountMenu(Gtk.Box):
 
         self._accounts_listbox = Gtk.ListBox()
         self._accounts_listbox.set_sort_func(self._sort_func)
-        self._accounts_listbox.get_style_context().add_class('settings-box')
+        self._accounts_listbox.get_style_context().add_class(
+            'accounts-menu-listbox')
         self._accounts_listbox.connect('row-activated',
                                        self._on_account_row_activated)
 
@@ -316,7 +317,7 @@ class AccountSubMenu(Gtk.ListBox):
         Gtk.ListBox.__init__(self)
         self.set_vexpand(True)
         self.set_hexpand(True)
-        self.get_style_context().add_class('settings-box')
+        self.get_style_context().add_class('accounts-menu-listbox')
 
         self._account = account
 
@@ -519,8 +520,10 @@ class AccountRow(Gtk.ListBoxRow):
         self._switch.set_vexpand(False)
 
         self._switch_state_label = Gtk.Label()
-        self._switch_state_label.set_xalign(1)
+        self._switch_state_label.set_xalign(0)
         self._switch_state_label.set_valign(Gtk.Align.CENTER)
+        label_width = max(len(p_('Switch', 'On')), len(p_('Switch', 'Off')))
+        self._switch_state_label.set_width_chars(label_width)
         self._set_label(account_enabled)
 
         self._switch.connect(
@@ -549,7 +552,7 @@ class AccountRow(Gtk.ListBoxRow):
         self._set_label(state)
 
     def _set_label(self, active: bool) -> None:
-        text = Q_('?switch:On') if active else Q_('?switch:Off')
+        text = p_('Switch', 'On') if active else p_('Switch', 'Off')
         self._switch_state_label.set_text(text)
 
     def _on_enable_switch(self,
@@ -637,7 +640,7 @@ class GenericSettingPage(Gtk.Box):
         self.account = account
 
         self.listbox = SettingsBox(account)
-        self.listbox.get_style_context().add_class('accounts-settings-border')
+        self.listbox.get_style_context().add_class('border')
         self.listbox.set_selection_mode(Gtk.SelectionMode.NONE)
         self.listbox.set_vexpand(False)
         self.listbox.set_valign(Gtk.Align.END)
