@@ -37,22 +37,22 @@ from __future__ import annotations
 
 from typing import Any
 from typing import Callable
-from typing import Optional
 from typing import cast
+from typing import Optional
 
 import os
 import sys
 from urllib.parse import unquote
 
-from nbxmpp.namespaces import Namespace
-from nbxmpp import JID
-from nbxmpp.protocol import InvalidJid
-from nbxmpp.const import ConnectionType
-from nbxmpp.const import ConnectionProtocol
+from gi.repository import Gdk
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import Gtk
-from gi.repository import Gdk
+from nbxmpp import JID
+from nbxmpp.const import ConnectionProtocol
+from nbxmpp.const import ConnectionType
+from nbxmpp.namespaces import Namespace
+from nbxmpp.protocol import InvalidJid
 
 import gajim
 from gajim.common import app
@@ -62,34 +62,33 @@ from gajim.common import ged
 from gajim.common import idle
 from gajim.common.application import CoreApplication
 from gajim.common.const import GAJIM_FAQ_URI
-from gajim.common.const import GAJIM_WIKI_URI
 from gajim.common.const import GAJIM_SUPPORT_JID
+from gajim.common.const import GAJIM_WIKI_URI
 from gajim.common.exceptions import GajimGeneralException
 from gajim.common.helpers import load_json
 from gajim.common.helpers import open_uri
 from gajim.common.i18n import _
 
-from gajim.gui import menus
-from gajim.gui import structs
-from gajim.gui.about import AboutDialog
-from gajim.gui.accounts import AccountsWindow
-from gajim.gui.avatar import AvatarStorage
-from gajim.gui.builder import get_builder
-from gajim.gui.const import ACCOUNT_ACTIONS
-from gajim.gui.const import ALWAYS_ACCOUNT_ACTIONS
-from gajim.gui.const import APP_ACTIONS
-from gajim.gui.const import FEATURE_ACCOUNT_ACTIONS
-from gajim.gui.const import ONLINE_ACCOUNT_ACTIONS
-from gajim.gui.dialogs import DialogButton
-from gajim.gui.dialogs import ConfirmationDialog
-from gajim.gui.dialogs import ShortcutsWindow
-from gajim.gui.discovery import ServiceDiscoveryWindow
-from gajim.gui.start_chat import StartChatDialog
-from gajim.gui.util import get_app_window
-from gajim.gui.util import get_app_windows
-from gajim.gui.util import load_user_iconsets
-from gajim.gui.util import open_window
-
+from gajim.gtk import menus
+from gajim.gtk import structs
+from gajim.gtk.about import AboutDialog
+from gajim.gtk.accounts import AccountsWindow
+from gajim.gtk.avatar import AvatarStorage
+from gajim.gtk.builder import get_builder
+from gajim.gtk.const import ACCOUNT_ACTIONS
+from gajim.gtk.const import ALWAYS_ACCOUNT_ACTIONS
+from gajim.gtk.const import APP_ACTIONS
+from gajim.gtk.const import FEATURE_ACCOUNT_ACTIONS
+from gajim.gtk.const import ONLINE_ACCOUNT_ACTIONS
+from gajim.gtk.dialogs import ConfirmationDialog
+from gajim.gtk.dialogs import DialogButton
+from gajim.gtk.dialogs import ShortcutsWindow
+from gajim.gtk.discovery import ServiceDiscoveryWindow
+from gajim.gtk.start_chat import StartChatDialog
+from gajim.gtk.util import get_app_window
+from gajim.gtk.util import get_app_windows
+from gajim.gtk.util import load_user_iconsets
+from gajim.gtk.util import open_window
 
 ActionListT = list[tuple[str,
                          Callable[[Gio.SimpleAction, GLib.Variant], Any]]]
@@ -220,8 +219,8 @@ class GajimApplication(Gtk.Application, CoreApplication):
         return [option]
 
     def _startup(self) -> None:
-        if sys.platform == 'win32':
-            # Changing the PANGOCAIRO_BACKEND is necessary on Windows
+        if sys.platform in ('win32', 'darwin'):
+            # Changing the PANGOCAIRO_BACKEND is necessary on Windows/MacOS
             # to render colored emoji glyphs
             os.environ['PANGOCAIRO_BACKEND'] = 'fontconfig'
 
@@ -234,7 +233,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
         builder = get_builder('application_menu.ui')
         self.set_menubar(cast(Gio.Menu, builder.get_object('menubar')))
 
-        from gajim.gui import notification
+        from gajim.gtk import notification
         notification.init()
 
         self.avatar_storage = AvatarStorage()
@@ -244,18 +243,12 @@ class GajimApplication(Gtk.Application, CoreApplication):
         idle.Monitor.set_interval(app.settings.get('autoawaytime') * 60,
                                   app.settings.get('autoxatime') * 60)
 
-        if sys.platform == 'darwin':
-            # TODO: Remove if colored emoji rendering works well on
-            # Windows and MacOS
-            from gajim.gui.emoji_chooser import emoji_chooser
-            emoji_chooser.load()
-
         from gajim.gui_interface import Interface
 
         self.interface = Interface()
         self.interface.run(self)
 
-        from gajim.gui.status_icon import StatusIcon
+        from gajim.gtk.status_icon import StatusIcon
         self.systray = StatusIcon()
 
         self._add_app_actions()
@@ -271,7 +264,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
                             ged.CORE,
                             self._on_feature_discovered)
 
-        from gajim.gui.main import MainWindow
+        from gajim.gtk.main import MainWindow
         MainWindow()
 
         GLib.timeout_add(100, self._auto_connect)
@@ -308,7 +301,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
             if cmd == 'join':
                 if len(accounts) == 1:
                     self.activate_action(
-                        'groupchat-join',
+                        'open-chat',
                         GLib.Variant('as', [accounts[0], jid]))
                 else:
                     self.activate_action(
@@ -421,11 +414,10 @@ class GajimApplication(Gtk.Application, CoreApplication):
             ('add-contact', self._on_add_contact_action),
             ('copy-text', self._on_copy_text_action),
             ('open-link', self._on_open_link_action),
-            ('open-mail', self._on_open_mail_action),
             ('remove-history', self._on_remove_history_action),
             ('create-groupchat', self._on_create_groupchat_action),
             ('forget-groupchat', self._on_forget_groupchat_action),
-            ('groupchat-join', self._on_groupchat_join_action),
+            ('open-chat', self._on_open_chat_action),
             ('show', self._on_show),
         ]
 
@@ -452,7 +444,6 @@ class GajimApplication(Gtk.Application, CoreApplication):
     def _connect_account_actions(self, account: str) -> None:
         actions = [
             ('bookmarks', self._on_bookmarks_action),
-            ('open-chat', self._on_open_chat_action),
             ('add-contact', self._on_add_contact_account_action),
             ('services', self._on_services_action),
             ('profile', self._on_profile_action),
@@ -804,14 +795,6 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
         app.window.mark_as_read(params.account, params.jid)
 
-    @staticmethod
-    def _on_open_mail_action(_action: Gio.SimpleAction,
-                             param: GLib.Variant) -> None:
-        uri = param.get_string()
-        if not uri.startswith('mailto:'):
-            uri = 'mailto:%s' % uri
-        open_uri(uri)
-
     @staticmethod
     def _on_open_link_action(_action: Gio.SimpleAction,
                              param: GLib.Variant) -> None:
@@ -869,12 +852,6 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
         app.storage.archive.remove_history(params.account, params.jid)
 
-    @staticmethod
-    def _on_groupchat_join_action(_action: Gio.SimpleAction,
-                                  param: GLib.Variant) -> None:
-        account, jid = param.get_strv()
-        open_window('GroupchatJoin', account=account, jid=jid)
-
     @staticmethod
     def _on_show(_action: Gio.SimpleAction, param: GLib.Variant) -> None:
         app.window.show()
