@@ -17,15 +17,15 @@ from __future__ import annotations
 from typing import Optional
 from typing import Union
 
-import sys
 import logging
+import sys
 import time
+from urllib.parse import urlparse
 
 from gi.repository import Gdk
-from gi.repository import GLib
 from gi.repository import Gio
+from gi.repository import GLib
 from gi.repository import Gtk
-
 from nbxmpp.errors import StanzaError
 from nbxmpp.protocol import JID
 from nbxmpp.structs import MessageProperties
@@ -35,27 +35,30 @@ from gajim.common import events
 from gajim.common import helpers
 from gajim.common import preview_helpers
 from gajim.common.commands import ChatCommands
-from gajim.common.i18n import _
 from gajim.common.const import CallType
+from gajim.common.i18n import _
 from gajim.common.modules.contacts import BareContact
 from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.modules.contacts import GroupchatParticipant
+from gajim.common.preview_helpers import format_geo_coords
+from gajim.common.preview_helpers import split_geo_uri
 from gajim.common.structs import OutgoingMessage
 from gajim.common.types import ChatContactT
-from gajim.gui.dialogs import ErrorDialog
+from gajim.common.util.text import remove_invalid_xml_chars
 
-from .chat_banner import ChatBanner
-from .chat_function_page import ChatFunctionPage
-from .chat_function_page import FunctionMode
-from .const import TARGET_TYPE_URI_LIST
-from .control import ChatControl
-from .message_actions_box import MessageActionsBox
-from .message_input import MessageInputTextView
-from .util import EventHelper
-from .util import open_window
-from .util import set_urgency_hint
+from gajim.gtk.chat_banner import ChatBanner
+from gajim.gtk.chat_function_page import ChatFunctionPage
+from gajim.gtk.chat_function_page import FunctionMode
+from gajim.gtk.const import TARGET_TYPE_URI_LIST
+from gajim.gtk.control import ChatControl
+from gajim.gtk.dialogs import ErrorDialog
+from gajim.gtk.message_actions_box import MessageActionsBox
+from gajim.gtk.message_input import MessageInputTextView
+from gajim.gtk.util import EventHelper
+from gajim.gtk.util import open_window
+from gajim.gtk.util import set_urgency_hint
 
-log = logging.getLogger('gajim.gui.chatstack')
+log = logging.getLogger('gajim.gtk.chatstack')
 
 
 class ChatStack(Gtk.Stack, EventHelper):
@@ -111,7 +114,7 @@ class ChatStack(Gtk.Stack, EventHelper):
         self._drop_area.set_no_show_all(True)
         self._drop_area.set_hexpand(True)
         self._drop_area.set_vexpand(True)
-        self._drop_area.set_name('DropArea')
+        self._drop_area.get_style_context().add_class('solid-background')
         self._drop_area.add(dnd_icon)
         self._drop_area.add(dnd_label)
 
@@ -188,6 +191,8 @@ class ChatStack(Gtk.Stack, EventHelper):
         client = app.get_client(account)
         self._current_contact = client.get_module('Contacts').get_contact(jid)
 
+        app.preview_manager.clear_previews()
+
         self._chat_banner.switch_contact(self._current_contact)
         self._chat_control.switch_contact(self._current_contact)
         self._message_action_box.switch_contact(self._current_contact)
@@ -248,7 +253,7 @@ class ChatStack(Gtk.Stack, EventHelper):
             'switch_contact', self._current_contact)
 
         if old_primary_clipboard is not None:
-            GLib.idle_add(clipboard.set_text,  # pyright: ignore
+            GLib.idle_add(clipboard.set_text,
                           old_primary_clipboard,
                           -1)
 
@@ -372,6 +377,16 @@ class ChatStack(Gtk.Stack, EventHelper):
         if not event.msgtxt or event.properties.is_sent_carbon:
             return
 
+        client = app.get_client(event.account)
+        contact = client.get_module('Contacts').get_contact(event.jid)
+        if isinstance(contact, GroupchatContact):
+            # MUC messages may be received after some delay, so make sure we
+            # don't issue notifications for our own messages.
+            self_contact = contact.get_self()
+            if (self_contact is not None and
+                    self_contact.name == event.properties.muc_nickname):
+                return
+
         if app.window.is_chat_active(event.account, event.jid):
             return
 
@@ -389,8 +404,11 @@ class ChatStack(Gtk.Stack, EventHelper):
         is_previewable = app.preview_manager.is_previewable(
             text, additional_data)
         if is_previewable:
-            if text.startswith('geo:'):
-                text = _('Location')
+            scheme = urlparse(text).scheme
+            if scheme == 'geo':
+                location = split_geo_uri(text)
+                text = format_geo_coords(
+                    float(location.lat), float(location.lon))
             else:
                 file_name = preview_helpers.filename_from_uri(text)
                 _icon, file_type = preview_helpers.guess_simple_file_type(text)
@@ -434,7 +452,7 @@ class ChatStack(Gtk.Stack, EventHelper):
             if text.startswith('/me') or text.startswith('/me\n'):
                 name = contact.name
                 if isinstance(contact, GroupchatContact):
-                    name = contact.nickname
+                    name = event.properties.muc_nickname
                 text = f'* {name} {text[3:]}'
 
         app.ged.raise_event(
@@ -531,6 +549,7 @@ class ChatStack(Gtk.Stack, EventHelper):
 
         app.window.get_action('quote').set_enabled(joined)
         app.window.get_action('mention').set_enabled(joined)
+        app.window.get_action('retract-message').set_enabled(joined)
 
     def _update_participant_actions(self,
                                     contact: GroupchatParticipant) -> None:
@@ -557,16 +576,19 @@ class ChatStack(Gtk.Stack, EventHelper):
             app.call_manager.start_call(account, jid, CallType.VIDEO)
 
         elif action_name.startswith('send-file'):
+            method = None
             name = action.get_name()
             if 'httpupload' in name:
-                app.interface.start_file_transfer(contact, method='httpupload')
-                return
+                method = 'httpupload'
 
             if 'jingle' in name:
-                app.interface.start_file_transfer(contact, method='jingle')
-                return
+                method = 'jingle'
 
-            app.interface.start_file_transfer(contact)
+            uris = None
+            if param is not None:
+                uris = param.get_strv() or None
+            self._show_chat_function_page(
+                FunctionMode.SEND_FILE, method, uris)
 
         elif action_name == 'add-to-roster':
             if (isinstance(contact, GroupchatParticipant) and
@@ -661,20 +683,26 @@ class ChatStack(Gtk.Stack, EventHelper):
                         _context: Gdk.DragContext,
                         _x_coord: int,
                         _y_coord: int,
-                        _time: int
+                        time: int
                         ) -> bool:
+
+        if time == 0:
+            # Workaround for https://gitlab.gnome.org/GNOME/gtk/-/issues/5518
+            return False
+
         self._drop_area.set_no_show_all(False)
         self._drop_area.show_all()
         return True
 
     def _show_chat_function_page(self,
                                  function_mode: FunctionMode,
-                                 data: Optional[str] = None
+                                 data: Optional[str] = None,
+                                 files: Optional[list[str]] = None
                                  ) -> None:
 
         assert self._current_contact is not None
         self._chat_function_page.set_mode(
-            self._current_contact, function_mode, data)
+            self._current_contact, function_mode, data, files)
         self.set_transition_type(Gtk.StackTransitionType.SLIDE_UP_DOWN)
         self.set_visible_child_name('function')
 
@@ -699,7 +727,6 @@ class ChatStack(Gtk.Stack, EventHelper):
         self._chat_control.add_info_message(message)
 
     def _on_send_message(self) -> None:
-        self._message_action_box.msg_textview.replace_emojis()
         message = self._message_action_box.msg_textview.get_text()
         if message.startswith('//'):
             # Escape sequence for chat commands
@@ -724,8 +751,8 @@ class ChatStack(Gtk.Stack, EventHelper):
 
         client = app.get_client(contact.account)
 
-        message = helpers.remove_invalid_xml_chars(message)
-        if message in ('', None, '\n'):
+        message = remove_invalid_xml_chars(message)
+        if message in ('', '\n'):
             return
 
         label = self._message_action_box.get_seclabel()
