@@ -22,29 +22,27 @@ from __future__ import annotations
 from typing import Any
 from typing import Optional
 
+import logging
 from collections import defaultdict
 
-import logging
-import sys
-
-from gi.repository import Gtk
 from gi.repository import Gdk
-from gi.repository import GdkPixbuf
 from gi.repository import GLib
+from gi.repository import Gtk
 from gi.repository import Pango
 
 from gajim.common import app
 from gajim.common import ged
 from gajim.common.events import MessageSent
 from gajim.common.ged import EventHelper
-from gajim.common.i18n import LANG
 from gajim.common.i18n import _
-from gajim.common.styling import process
+from gajim.common.i18n import LANG
 from gajim.common.styling import PlainBlock
+from gajim.common.styling import process
 from gajim.common.types import ChatContactT
 
-from .chat_action_processor import ChatActionProcessor
-from .util import scroll_to_end
+from gajim.gtk.chat_action_processor import ChatActionProcessor
+from gajim.gtk.const import MAX_MESSAGE_LENGTH
+from gajim.gtk.util import scroll_to_end
 
 if app.is_installed('GSPELL'):
     from gi.repository import Gspell  # pylint: disable=ungrouped-imports
@@ -58,7 +56,7 @@ FORMAT_CHARS: dict[str, str] = {
     'pre': '`',
 }
 
-log = logging.getLogger('gajim.gui.message_input')
+log = logging.getLogger('gajim.gtk.message_input')
 
 
 class MessageInputTextView(Gtk.TextView, EventHelper):
@@ -116,7 +114,9 @@ class MessageInputTextView(Gtk.TextView, EventHelper):
 
     @property
     def is_correcting(self) -> bool:
-        assert self._contact is not None
+        if self._contact is None:
+            return False
+
         return self._correcting[self._contact]
 
     def get_last_message_id(self, contact: ChatContactT) -> Optional[str]:
@@ -179,7 +179,7 @@ class MessageInputTextView(Gtk.TextView, EventHelper):
             oob_url = event.additional_data.get_value('gajim', 'oob_url')
             if oob_url == event.message:
                 # Don't allow to correct HTTP Upload file transfer URLs
-                self._last_message_id.pop(self._contact)
+                self._last_message_id[self._contact] = None
             else:
                 self._last_message_id[self._contact] = event.message_id
 
@@ -225,7 +225,7 @@ class MessageInputTextView(Gtk.TextView, EventHelper):
         assert isinstance(lang, str)
         lang = Gspell.language_lookup(lang)
         if lang is None:
-            lang = Gspell.language_get_default()
+            return Gspell.language_get_default()
         return lang
 
     def _on_language_changed(self,
@@ -312,7 +312,7 @@ class MessageInputTextView(Gtk.TextView, EventHelper):
 
         self._clear_tags()
 
-        if len(text) > 10000:
+        if len(text) > MAX_MESSAGE_LENGTH:
             # Limit message styling processing
             return
 
@@ -347,8 +347,7 @@ class MessageInputTextView(Gtk.TextView, EventHelper):
     def get_text(self) -> str:
         buf = self.get_buffer()
         start, end = buf.get_bounds()
-        text = self.get_buffer().get_text(start, end, True)
-        return text
+        return self.get_buffer().get_text(start, end, True)
 
     def _on_toggle_spell_check(self, *args: Any) -> None:
         if not app.is_installed('GSPELL'):
@@ -418,60 +417,6 @@ class MessageInputTextView(Gtk.TextView, EventHelper):
             buf.get_iter_at_offset(start_offset),
             buf.get_iter_at_offset(end_offset + 2))
 
-    def replace_emojis(self) -> None:
-        if sys.platform != 'darwin':
-            # TODO: Remove if colored emoji rendering works well on MacOS
-            return
-
-        theme = app.settings.get('emoticons_theme')
-        if not theme or theme == 'font':
-            return
-
-        def _replace(anchor: Gtk.TextChildAnchor) -> None:
-            if anchor is None:
-                return
-            image = anchor.get_widgets()[0]
-            if hasattr(image, 'codepoint'):
-                # found emoji
-                codepoint = getattr(image, 'codepoint')
-                self._replace_char_at_iter(iter_, codepoint)
-                image.destroy()
-
-        iter_ = self.get_buffer().get_start_iter()
-        _replace(iter_.get_child_anchor())
-
-        while iter_.forward_char():
-            _replace(iter_.get_child_anchor())
-
-    def _replace_char_at_iter(self,
-                              iter_: Gtk.TextIter,
-                              new_char: str
-                              ) -> None:
-        buf = self.get_buffer()
-        iter_2 = iter_.copy()
-        iter_2.forward_char()
-        buf.delete(iter_, iter_2)
-        buf.insert(iter_, new_char)
-
-    def insert_emoji(self, codepoint: str, pixbuf: GdkPixbuf.Pixbuf) -> None:
-        buf = self.get_buffer()
-        if buf.get_char_count():
-            # buffer contains text
-            buf.insert_at_cursor(' ')
-
-        insert_mark = buf.get_insert()
-        insert_iter = buf.get_iter_at_mark(insert_mark)
-
-        if pixbuf is None:
-            buf.insert(insert_iter, codepoint)
-        else:
-            anchor = buf.create_child_anchor(insert_iter)
-            image = Gtk.Image.new_from_pixbuf(pixbuf)
-            setattr(image, 'codepoint', codepoint)
-            image.show()
-            self.add_child_at_anchor(image, anchor)
-        buf.insert_at_cursor(' ')
-
     def clear(self, *args: Any) -> None:
         buf = self.get_buffer()
         start, end = buf.get_bounds()
