@@ -13,30 +13,36 @@
 # along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import annotations
+
 from typing import Any
+from typing import Callable
+from typing import cast
 from typing import Optional
 from typing import Union
-from typing import cast
 
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import Pango
-
 from nbxmpp import JID
 
 from gajim.common import app
 from gajim.common.const import AvatarSize
-from gajim.common.i18n import _
+from gajim.common.events import MucDecline
+from gajim.common.events import MucInvitation
 from gajim.common.events import Notification
 from gajim.common.events import SubscribePresenceReceived
 from gajim.common.events import UnsubscribedPresenceReceived
-from gajim.common.events import MucInvitation
-from gajim.common.events import MucDecline
 from gajim.common.helpers import get_groupchat_name
+from gajim.common.i18n import _
 
-from .menus import get_subscription_menu
-from .util import open_window
+from gajim.gtk.menus import get_subscription_menu
+from gajim.gtk.util import open_window
+
+NotificationActionListT = list[
+    tuple[str,
+          Callable[[Gio.SimpleAction, GLib.Variant], Any],
+          Optional[str]]]
 
 
 class NotificationManager(Gtk.ListBox):
@@ -64,16 +70,19 @@ class NotificationManager(Gtk.ListBox):
         self._remove_actions()
 
     def _add_actions(self) -> None:
-        actions = [
+        actions: NotificationActionListT = [
             ('subscription-accept', self._on_subscription_accept, 'as'),
             ('subscription-deny', self._on_subscription_deny, 's'),
+            ('subscription-deny-all', self._on_subscription_deny_all, None),
             ('subscription-block', self._on_subscription_block, 's'),
             ('subscription-report', self._on_subscription_report, 's'),
         ]
         for action in actions:
             action_name, func, typ = action
+            if typ is not None:
+                typ = GLib.VariantType.new(typ)
             act = Gio.SimpleAction.new(
-                f'{action_name}-{self._account}', GLib.VariantType.new(typ))
+                f'{action_name}-{self._account}', typ)
             act.connect('activate', func)
             app.window.add_action(act)
 
@@ -91,6 +100,11 @@ class NotificationManager(Gtk.ListBox):
         assert sub_deny is not None
         sub_deny.set_enabled(online)
 
+        sub_deny_all = app.window.lookup_action(
+            f'subscription-deny-all-{self._account}')
+        assert sub_deny_all is not None
+        sub_deny_all.set_enabled(online)
+
         sub_block = app.window.lookup_action(
             f'subscription-block-{self._account}')
         assert sub_block is not None
@@ -105,6 +119,7 @@ class NotificationManager(Gtk.ListBox):
         actions = [
             'subscription-accept',
             'subscription-deny',
+            'subscription-deny-all',
             'subscription-block',
             'subscription-report',
         ]
@@ -165,6 +180,17 @@ class NotificationManager(Gtk.ListBox):
         if row is not None:
             row.destroy()
 
+    def _on_subscription_deny_all(self,
+                                  _action: Gio.SimpleAction,
+                                  _param: GLib.Variant
+                                  ) -> None:
+
+        for row in cast(list[NotificationRow], self.get_children()):
+            if row.type != 'subscribe':
+                continue
+            self._deny_request(row.jid)
+            row.destroy()
+
     def _deny_request(self, jid: str) -> None:
         self._client.get_module('Presence').unsubscribed(jid)
 
